@@ -21,7 +21,7 @@ from collections import namedtuple
 from tornado import gen
 from nbformat.v4 import new_notebook
 from .cortx_authenticator import CortxAuthenticator
-from .utils import (MultiPartUploadHelper,get_key,get_path)
+from .utils import (MultiPartUploadHelper,_get_key,_get_path, _get_full_path)
 import json 
 
 import nbformat
@@ -161,8 +161,8 @@ class CortxJupyter(ContentsManager):
 #     return '/' + key[len(config.prefix):]
 
 
-def _final_path_component(key_or_path):
-    return key_or_path.split('/')[-1]
+# def _get_full_path(key_or_path):
+#     return key_or_path.split('/')[-1]
 
 def _copy_sort_key(key):
     return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
@@ -268,7 +268,7 @@ def _get_any(config, path, content, type, mimetype, format, decode):
         last_modified_str, "%Y-%m-%dT%H:%M:%S.%fZ")
 
     return {
-        'name': _final_path_component(path),
+        'name': _get_full_path(path),
         'path': path,
         'type': type,
         'mimetype': mimetype,
@@ -291,7 +291,7 @@ def _get_directory(config, path, content):
     all_keys = {key for (key, _) in keys}
 
     return {
-        'name': _final_path_component(path),
+        'name': _get_full_path(path),
         'path': path,
         'type': 'directory',
         'mimetype': None,
@@ -302,16 +302,16 @@ def _get_directory(config, path, content):
         'content': ([
             {
                 'type': 'directory',
-                'name': _final_path_component(directory),
-                'path': get_path(config, directory),
+                'name': _get_full_path(directory),
+                'path': _get_path(config, directory),
             }
             for directory in directories
             if directory not in all_keys
         ] + [
             {
                 'type': _type_from_path_not_directory(key),
-                'name': _final_path_component(key),
-                'path': get_path(config, key),
+                'name': _get_full_path(key),
+                'path': _get_path(config, key),
                 'last_modified': last_modified,
             }
             for (key, last_modified) in keys
@@ -382,7 +382,7 @@ def _save_chunk(config, chunk, content_bytes, path, type, mimetype):
 @gen.coroutine
 def _save_bytes(config, content_bytes, path, type, mimetype):
 
-    object_name = get_key(config, path)
+    object_name = _get_key(config, path)
     response = _put_object(config, config.bucket_name, content_bytes, object_name)
     last_modified = f"{datetime.datetime.now():%a, %d %b %Y %H:%M:%S GMT}"
 
@@ -391,7 +391,7 @@ def _save_bytes(config, content_bytes, path, type, mimetype):
 
 def _saved_model(path, type, mimetype, last_modified):
     return {
-        'name': _final_path_component(path),
+        'name': _get_full_path(path),
         'path': path,
         'type': type,
         'mimetype': mimetype,
@@ -460,7 +460,7 @@ def _delete_checkpoint(config, checkpoint_id, path):
 
 @gen.coroutine
 def _list_checkpoints(config, path):
-    key_prefix = get_key(config, path + '/' + CHECKPOINT_NAME + '/')
+    key_prefix = _get_key(config, path + '/' + CHECKPOINT_NAME + '/')
     keys, _ = yield _list_immediate_child_keys_and_directories(config, key_prefix)
     return [
         {
@@ -480,8 +480,8 @@ def _rename(config, old_path, new_path):
         raise HTTPServerError(400, "Target already exists")
 
     type = yield _type_from_path(config, old_path)
-    old_key = get_key(config, old_path)
-    new_key = get_key(config, new_path)
+    old_key = _get_key(config, old_path)
+    new_key = _get_key(config, new_path)
 
     def replace_key_prefix(string):
         return new_key + string[len(old_key):]
@@ -520,7 +520,7 @@ def _delete(config, path):
         raise HTTPServerError(400, "Can't delete root")
 
     type = _type_from_path(config, path)
-    root_key = get_key(config, path)
+    root_key = _get_key(config, path)
 
     object_key = \
         [] if type == 'directory' else \
@@ -607,8 +607,8 @@ def _copy(config, from_path, to_path):
         to_name = yield _increment_filename(config, name, to_path, insert='-Copy')
         to_path = u'{0}/{1}'.format(to_path, to_name)
 
-    from_key = get_key(config, from_path)
-    to_key = get_key(config, to_path)
+    from_key = _get_key(config, from_path)
+    to_key = _get_key(config, to_path)
 
     yield _copy_key(config, from_key, to_key)
     return {
