@@ -31,9 +31,12 @@ class MultiPartUploadHelper:
         del self._store[key]
 
 
-def get_key(config, path):
+def _get_key(config, path):
     return config.prefix + path.lstrip('/')
 
 
-def get_path(config, key):
-    return '/' + key[len(config.prefix):]
\ No newline at end of file
+def _get_path(config, key):
+    return '/' + key[len(config.prefix):]
+
+def _get_full_path(key_or_path):
+    return key_or_path.split('/')[-1]
\ No newline at end of file
